@@ -138,7 +138,10 @@ class AZgard(BaseConsoleInvokedComponent):
         smiles_ids, scores = self._parse_output_data_json(path=output_json_path)
 
         # apply transformation
-        transformed_scores = self._transformation_function(scores, self.parameters.specific_parameters)
+        transform_params = self.parameters.specific_parameters.get(
+            self.component_specific_parameters.TRANSFORMATION, {}
+        )
+        transformed_scores = self._transformation_function(scores, transform_params)
 
         # clean up
         if os.path.isdir(tmp_dir):
