@@ -7,8 +7,8 @@ from reinvent_scoring.scoring.score_components import TanimotoSimilarity, \
     SASComponent, MolWeight, PSA, RotatableBonds, HBD_Lipinski, HBA_Lipinski, \
     NumRings, AZlogD74, HLMClint, SlogP, \
     RHClint, HHClint, SolubilityDD, HERG, CACO2Intrinsic, CACO2Efflux, AZdock, RatPKPiP, Top20, GraphLength, \
-    NumberOfStereoCenters,\
-    LinkerLengthRatio, LinkerGraphLength, LinkerEffectiveLength
+    NumberOfStereoCenters, \
+    LinkerLengthRatio, LinkerGraphLength, LinkerEffectiveLength, DockStream
 from reinvent_scoring.scoring.score_components import BaseScoreComponent
 from reinvent_scoring.scoring.enums import ScoringFunctionComponentNameEnum
 from reinvent_scoring.scoring.score_components.pip.pip_log_prediction_component import PiPLogPredictionComponent
@@ -65,9 +65,14 @@ class ScoreComponentFactory:
             enum.KPUU_PIP: PiPLogPredictionComponent,
             enum.LINKER_GRAPH_LENGTH: LinkerGraphLength,
             enum.LINKER_EFFECTIVE_LENGTH: LinkerEffectiveLength,
-            enum.LINKER_LENGTH_RATIO: LinkerLengthRatio
+            enum.LINKER_LENGTH_RATIO: LinkerLengthRatio,
+            enum.DOCKSTREAM: DockStream
         }
         return component_map
 
     def create_score_components(self) -> [BaseScoreComponent]:
-        return [self._current_components.get(p.component_type)(p) for p in self._parameters]
+        try:
+            components = [self._current_components.get(p.component_type)(p) for p in self._parameters]
+        except KeyError as ex:
+            raise ex
+        return components
